import {
  validateIdcard
} from './validate_idcard'
/**
 * @param {string} path
 * @returns {Boolean}
 */
export function isExternal(path) {
  return /^(https?:|mailto:|tel:)/.test(path)
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validUsername(str) {
  const valid_map = ['admin', 'editor']
  return valid_map.indexOf(str.trim()) >= 0
}

/**
 * @param {string} url
 * @returns {Boolean}
 */
export function validURL(url) {
  const reg = /^(https?|ftp):\/\/([a-zA-Z0-9.-]+(:[a-zA-Z0-9.&%$-]+)*@)*((25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])){3}|([a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(:[0-9]+)*(\/($|[a-zA-Z0-9.,?'\\+&%$#=~_-]+))*$/
  return reg.test(url)
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validLowerCase(str) {
  const reg = /^[a-z]+$/
  return reg.test(str)
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validUpperCase(str) {
  const reg = /^[A-Z]+$/
  return reg.test(str)
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validAlphabets(str) {
  const reg = /^[A-Za-z]+$/
  return reg.test(str)
}

/**
 * @param {string} email
 * @returns {Boolean}
 */
export function validEmail(email) {
  const reg = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
  return reg.test(email)
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function isString(str) {
  if (typeof str === 'string' || str instanceof String) {
    return true
  }
  return false
}

/**
 * @param {Array} arg
 * @returns {Boolean}
 */
export function isArray(arg) {
  if (typeof Array.isArray === 'undefined') {
    return Object.prototype.toString.call(arg) === '[object Array]'
  }
  return Array.isArray(arg)
}

// 身份证
export function validIDcard(rule, value, cb) {
  if (value) {
    if (!validateIdcard(value)) {
      cb(new Error('身份证号格式错误'))
    } else {
      cb()
    }
  } else {
    cb()
  }
}
/**
 * 金额
 * @param {*} s
 */
export function isAmount(s) {
  return /^\d{1,12}(\.\d{1,2})?$/.test(s)
}
export function validAmount(rule, value, cb) {
  if (!isAmount(value)) {
    cb(new Error('仅可以输入数字和小数点,保留小数点后两位'))
  } else {
    cb()
  }
}
/**
 * 数字
 * @param {*} s
 */
export function isNumber(s, m, n) {
  var re = new RegExp('^(0|[1-9][0-9]*)$', 'gim')
  return re.test(s)
}

export function validNumber(rule, value, cb) {
  if(!isNumber(value)) {
    cb(new Error('请输入数字'))
  } else {
    cb()
  }
}
/**
 * 百分比 最大值100
 * @param {*} s
 */
export function isPercentage(s) {
  return /^(\d?\d(\.\d{0,4})?|100(\.[0]{0,4})?)$/.test(s)
}
// 利率，百分百
export function validPercentage(rule, value, cb) {
  if (!isPercentage(value)) {
    cb(new Error('仅可以输入数字和小数点，最多保留四位小数，最大值100'))
  } else {
    cb()
  }
}